# Magic: The Gathering

[Magic: The Gathering](https://magic.wizards.com) - often shortened to MTG or Magic - is a tabletop
[collectible card game](/wiki/games/trading_card_games.md).
MTG is published by [Wizards of the Coast](https://company.wizards.com) - which are commonly
reffered to as Wizards.
In Magic: The Gathering there are many different formats that are all listed on
[the official website](https://magic.wizards.com/en/formats).
Rules can also be found on [Wizards website](https://magic.wizards.com/en/rules).

## Playing Online

There is a fully digital and online version of MTG called
[Magic: The Gathering Arena](https://magic.wizards.com/mtgarena) - or MTGA for short - that has
nearly the same rules as the tabletop variant.
Another alternative to playing fully digital is [Magic: The Gathering Online](https://www.mtgo.com).
This is also known as MTG Online or MTGO.

It is also possible to remotely play with tabletop cards.
This is most easily done on [Spelltable](https://spelltable.wizards.com/) which is an official
website by Wizards.
For playing Spelltable a [webcam](/wiki/webcams.md) is needed to be set up with a bird's eye view
over the playing field.
An alternative to a normal webcam is [DroidCam](/wiki/android/droidcam.md) for
[Android](/wiki/android.md) which is supported by the website itself.

Both Spelltable and MTGA use the same login credentials.

## Resources

There are many useful resources.
The this section provides a select few of them.
They are grouped by use case.

The first group of websites and apps provide a management interface aswell as a deck building
functionality.
Many of them also feature public decks.

- [Archidekt](https://archidekt.com/) is another popular deck building site.
  With the option to build commander decks based on a specific commander.
  It additionally features the display of public decks.
- [deckbox](https://deckbox.org/) is a very clean deck builder website.
- [deckstats.net](https://deckstats.net/) gives the option to build and analyze MTG(A) decks.
- [Delver Lens](https://www.delverlab.com/) is an [Android](/wiki/android.md) application for
  scanning cards and displaying its price.
  Following scanning the cards can be exported to a CSV file.
- [Dragon Shield MTG Card Manager](https://mtg.dragonshield.com/) is a collection and deck manager
  available both as an apple and [Android](/wiki/android.md) app and as a website.
  It features a card scanner for easy population of the collection
- [MTG Collection Builder](https://mtgcollectionbuilder.com/) is a website to organize and analyze
  your magic cards.
  It was specially made for collectors rather than players.
- [MTG Desktop Companion](https://www.mtgcompanion.org/) is a collection manager for MTG that
  includes prices, stats and a deck builder, aswell as the option to import and export to most of
  the used MTG deck formats.
  It is free and open-source.
  Its source code can be looked at on their
  [GitHub Page](https://github.com/nicho92/MtgDesktopCompanion).
- [Moxfield](https://www.moxfield.com/) is a popular deck building site.
  It also displays public decks.

The second group is about giving resources for building decks.
This can be done by providing public decks or showing which decks or cards are popular in which
format.

- [Tapped Out](https://tappedout.net/) is a website that among other things can suggest decks based
  on owned cards.
- [MTGGOLDFISH](https://www.mtggoldfish.com/) is a website for different topics regarding MTG.
  It features various decks including budget variants of it.
  Additionally it lists tournaments with decks played which can be a useful resource to understand
  the metagame.

The following websites provide useful information on cards or rulings of MTG.

- [EDHREC](https://edhrec.com/) is a website that can recommend cards based on an already existing
  commander or improve existing commander decks.
- [Hyperlinked Magic](https://yawgatog.com/resources/magic-rules/) is a website that features a
  hyperlinked HTML-version of MTG rules.
- [Scryfall](https://scryfall.com/) is a website to search and display Magic cards in specific
  printings.
- [What's in Standard?](https://whatsinstandard.com/) lists the sets that are currently legal in
  the standard format.
- [Magic Judges](https://chat.magicjudges.org/mtgrules/) is a live chat with judges to clarify the
  rules.

This group of resources is used to organize and join MTG tabletop, MTGA and MTGO tournaments.

- [Melee](https://melee.gg/) is a website that allows organization and joining of MTG and MTGA
  tournaments.
- [Magic: The Gathering Companion](https://magic.wizards.com/de/products/companion-app) is a mobile
  app that is officially made by Wizards.
  It features a tool to join tabletop tournaments in licensed stores and locations.

The following sites are focussed on analyzing decks and strategies for MTG Arena.

- [17Lands](https://www.17lands.com/faq) is a website focused on improving the draft of players in
  MTGA.
- [Untapped.gg](https://mtga.untapped.gg/) is a website and desktop app that analyzes MTGA decks and
  strategies.

This group of resources are websites on which MTG cards and supply can be bought.

- [Card Kingdom](https://www.cardkingdom.com/) is a website to shop MTG cards and supply.
  It ships from the united states of america.
- [cardmarket](https://www.cardmarket.com/) is a trading post for tabletop cards based in europe.
- [TCGPlayer](https://www.tcgplayer.com) is a trading post for tabletop cards that is used
  world-wide.

The following sites sell MTGO tix and sell or rent cards.

- [Cardhoarder](https://www.cardhoarder.com/) is a MTGO card selling site with renting service.
- [Goatbots](https://www.goatbots.com) is an MTGO website that sells cards and tix.
- [Mana Traders](https://www.manatraders.com/) is a renting service for MTGO cards, aswell as a way
  to buy tix.

Lastly [decklist.org](https://decklist.org/) can be used to neatly print out decklists.

## Deck Building

A central part of MTG is the composition of cards to a deck.
This section addresses the act of building a deck and important topics regarding deck composition.
Starting with the general topics of deck building this section will then split into multiple
subsections for building decks of different deck size.
This following general part is mainly based on a [YouTube](/wiki/youtube.md)
[video by Pompeius IIb.](https://www.youtube.com/watch?v=a37dLTiV58o).

It is generally recommended to stick with the minimum number of allowed cards in a format for a
deck.
This will assure that cards that are in the deck have a higher possibility to be drawn or in the
starting hand.

The first step of building a deck is setting up a clear strategy.

There are 3 main strategies.
Aggro decks are meant to build pressure and end the game fastly.
They are generally proactive and have minimal interaction with the opponent.
On the other side of the spectrum are control decks.
They counter the opponent and neutralize their strategy.
Due to this they are reactive.
These type of decks usually use a lot of card draw to get the advantage and find the correct counter
for a given opponent.
As a third theme combo decks use a combination of cards that are meant to finish the game.
They are based on finding these cards and performing the combo.
These kind of decks can use loops that can take a long time or even are infinite.

There are also combination of these strategies.
Aggro and control decks are called tempo or midrange decks.
Control and combo decks use the combo as a finisher to the game but are generally similar to control
decks.
The combination of aggro and control are generally fast, non-interactive and are synergy based Aggro
decks.

To find a strategy for your needs the following three questions are important to answer.

- How to end the game?
- When to end the game?
- How many interactions with the opponent?

The other big topic in deck building is card selection.

For picking a card multiple things have to be considered.
The card has to be efficient mana-wise.
It should therefore always be compared to other cards that are played similarly.
For creatures without any bonus attributes it is said that 1 Power and 1 Toughness per Mana is a
good starting point.
Additionally cards should fit the strategy and shouldn't be too specific.
Modal spells (1 card with multiple options) can be useful to be prepared for different
situations without too specific cards
They shouldn't be "win-more"-card and play good on their own.
The cards selected should include some few good concepts and synergies between cards.

Another thing to consider is the mana curve.
Mana curve describes the histogram of the mana values of the cards in a deck.
The curve should always begin at 1 and when the point is reached that wasspecified to end the game.
Using mana-acceleration a turn and its mana cost on the curve can be reduced or skipped.

The mana base is the land cards that are in a deck.
The mana base should include the right colors in the right ratio.
This ration can be calculated by calculating the mean of all used mana colors.
Sometimes it can be useful to increase the mana color of cards that are needed very early in the
game to ensure they can be played.
In non-mono decks double lands are useful but their restrictions they come with should be noted.
Approximately 1/3 of a deck should be reserved for land cards.

### Tipps on Building a Modern, Pauper or Standard Deck

This section will focus on the building of a 60 card modern, pauper or standard deck.
60 cards per deck is the minimum requirement for most formats like standard, modern and more.
This section is also mainly based on a [YouTube](/wiki/youtube.md)
[video by Pompeius IIb.](https://www.youtube.com/watch?v=a37dLTiV58o).

All tipps that are in the [above section](#deck-building) are to be considered in this section too.

As a rule of thumb the number of lands in a 60 card deck should be around
`18 + [cost of the most expensive card] (+- 1)`.

It is recommended to use playsets (4 cards) of cards or use multiple cards that are similar to
reduce the possibilities of draws.

### Tipps on Building a Commander Deck

This section will focus on the building of a 100 card commander deck.
100 cards per deck is most notably the minimum requirement for the commander format.
Therefor this section will mostly focus on commander

All tipps that are in the [above section](#deck-building) are to be considered in this section too.

For commander decks it is also important to select a commander to build the deck around.
Selecting the commander should be done in a step before choosing the strategy.

There are four main templates to build a commander.
The first three templates are fairly similar and will be explained as one in the
[following section](#9x7-8x8-and-7x9-deck-templates).
The last in the [section thereafter](#the-command-zone-deck-template).

#### 9x7, 8x8 and 7x9 Deck Templates

This section is mainly based on a [EDH Wiki entry](https://edh.fandom.com/wiki/7_by_9).
These three templates are considered to be very flexible.
Each theory gives a number of categories and a number of cards in that category.
Those categories of cards are intended to use many cards with similar effects to make the deck more
robust and redundant to draw similar cards consistently.

The categories are usually a combination of the following ones - though other categories are
possible.

- Card Draw
- Ramp
- Board Wipes
- Spot Removal
- Protection
- Reanimation Spells
- Tutors
- Haste Enablers
- Counterspells
- Buffs
- Blink Spells
- Token Makers
- Lifegain
- Lifegain Payoffs
- Graveyard Hate
- Pet Cards
- Miscellaneous

The three templates are the following:
The first is 7 categories by 9 cards (7x9) which will leave 36 cards for the mana base.
8 categories by 8 cards (8x8) which will leave 35 cards for the mana base.
9 categories by 7 cards (9x7) which will leave 36 cards for the mana base.

The category number and sizes can be adjusted.
It is considered that 10 cards in a category will make 2 cards of that category appear in a game and
a good chance to draw one card of that category in the starting hand.
categories with 5 cards are considered to make 1 card of that category appear in a game.

#### The Command Zone Deck Template

The fourth template is a template made by the [YouTube](/wiki/youtube.md) channel named
[Command Zone](https://www.youtube.com/@commandcast).
This section is therefore based on the corresponding
[video by Command Zone](https://www.youtube.com/watch?v=3K9PEeLG_6M).

It specifies the following categories and number cards in them.
The first card is the commander.
36 to 38 cards are used for the mana base.
10 cards are used for mana ramp.
10 cards are used for card draw.
5 cards each are used for targeted removal and board wipes.
The remaining 31 to 33 cards are used for the intended game strategy and deck plan.

#### Commander Staples

Staples are cards that are generally considered to be good in a given format.
This section addresses staples in the format commander.

This section will be divided by the colors of the cards.
It is based on a [video by VEX MTG](https://www.youtube.com/watch?v=hTzKOoQjfW4) on
[YouTube](/wiki/youtube.md).

##### White Mana Commander Staples

The following cards are considered to be staples in a deck containing enough white mana.

In the top tier are the following.

- Swords to Plowshares

Other good cards to always be considered are the following.

- Smothering Tithe
- Vanquish the Horde
- Farewell
- Teferi's Protection
- Esper Sentinel

##### Blue Mana Commander Staples

The following cards are considered to be staples in a deck containing enough blue mana.

In the top tier are the following.

- Cyclonic Rift

Other good cards to always be considered are the following.

- Rhystic Study
- Fierce Guardianship
- Mana Drain

##### Black Mana Commander Staples

The following cards are considered to be staples in a deck containing enough black mana.

In the top tier are the following.

- Bojuka Bog
- Toxic Deluge

Other good cards to always be considered are the following.

- Demonic Tutor
- Agadeem's Awakening

##### Red Mana Commander Staples

The following cards are considered to be staples in a deck containing enough red mana.

In the top tier are the following.

- Blasphemous Act

Other good cards to always be considered are the following.

- Dockside Extortionist
- Deflecting Swat
- Jeska's Will

##### Green Mana Commander Staples

The following cards are considered to be staples in a deck containing enough green mana.

In the top tier are the following.

- Bala Ged Recovery

Other good cards to always be considered are the following.

- Boseiju, Who Endures
- Cultivate
- Kodama's Reach
- Farseek
- Rampant Growth
- Nature's Lore
- Three Visits
- Yavimaya, Cradle of Growth

Green has many different options for mana ramp.
It is recommended to check for green mana ramp in the good cards category before going for the good
cards category in [the colorless staples section](#colorless-mana-commander-staples)

##### Multiple Mana Commander Staples

The following cards are considered to be staples in a deck containing multiple different colors of
mana.
These cards are only staples in decks which feature enough of these mana colors.
For easier navigation and organization the colors of the cards mana price are included in brackets
behind their names.

In the top tier are the following.

- Assasing's Trophy (cast for Black/Green)
- Anguished Unmaking (cast for White/Black)
- Ruinous Ultimatum (cast for White/Black/Red)
- The World Tree (taps for Green or any color; has a spell with White/Blue/Black/Red/Green)

Other good cards to always be considered are the following.

- Boros Charm (cast for White/Red)
- Rakdos Charm (cast for Black/Red)
- Rhythm of the Wild (cast for Red/Green)

##### Colorless Mana Commander Staples

The following cards are considered to be staples in a deck containing enough colorless mana.
Most cards in this deck can also be casted using no mana or any mana color which makes them staples
in all colors.

In the top tier are the following.

- Sol Ring
- Soul-Guide Lantern
- Vesuva
- Thespian's Stage

Other good cards to always be considered are the following.

- Arcane Signet
- Mana Crypt
- Command Tower
- Exotic Orchard
- Path of Ancestry- Field of the Dead
- Field of the Dead

### Example Decks and Updates

The following sections contain decks that have been made for various formats.
They are sectioned by the format they are intended for though they maybe are legal in other formats
aswell.

#### Commander

This section focusses on decks made for the format commander.

- CMD Mishra's Burnished Banner Precon by WotC
  - [Moxfield](https://www.moxfield.com/decks/2SN7rtbtuEy6rydE2U55gA)

##### CMD Mishra's Burnished Banner Upgraded by tiyn

This deck is put together by tiyn.
The base of this build is
[CMD Mishra's Burnished Banner Precon by WotC](https://www.moxfield.com/decks/2SN7rtbtuEy6rydE2U55gA).

The following resources have been used.

- 1:CMD Mishra's Burnished Banner Upgrade by The Command Zone
  - [Guide](https://www.youtube.com/watch?v=6rSkge558Ts) on [YouTube](/wiki/youtube.md)
- 2:CMD Mishra's Better Banner by Scrap Trawlers
  - [Guide](https://edhrec.com/articles/mishras-burnished-banner-upgrade-guide/) on EDHREC
- 3:CMD Mishra's Burnished Banner Precon Upgrade by TCGPlayers
  - [Guide](https://infinite.tcgplayer.com/article/Mishra-s-Burnished-Banner-MTG-Commander-Precon-Upgrade-Guide/6d6442ca-a7e4-4223-9014-2f8fd36d5dd5/)
    on TCGPlayer
- 4:CMD Mishra's Burnished Banner | Precon Upgrade Guide by Grazzet MTG
  - [Guide](https://www.youtube.com/watch?v=JoY_GkKKqps) on YouTube

The following changes to the deck have been made:

- 1 Dragonspark Reactor <- Slobad, Goblin Tinkerer (according to self)
- 1 Masterful Replication <- Thran Dynamo (according to self)
- 1 Obeka, Brute Chronologist <- Silas Renn, Seeker Adept (according to 4)
- 1 Scrap Trawler <- Metalwork Colossus (according to 4)
- 1 Wedding Invitation <- Faithless Looting (according to self)

The following changes to the deck are currently being considered:

- None

#### Modern

This section focusses on decks made for the format modern.

- MDN Budget Mono Green Tron by AffinityforMTG
  - [Decklist](https://www.mtggoldfish.com/deck/4103362#paper) on MTGGoldFish
- MDN Gondor Starter Precon by WotC
  - [Decklist](https://magic.wizards.com/en/news/announcements/the-lord-of-the-rings-tales-of-middle-earth-starter-kit-decklists)
    on Wizards
- MDN Izzet Prowess (Budget) by Xaranthilurozox
  - [Decklist](https://www.mtggoldfish.com/deck/3311260#paper) on MTGGoldFish
- MDN Izzet Prowess by MoreTimes
  - [Decklist](https://www.mtggoldfish.com/deck/5888133#paper) on MTGGoldFish
- MDN Izzet Prowess by IslandGoSAMe
  - [Guide](https://www.youtube.com/watch?v=htwBuoGM4b8) on [YouTube](/wiki/youtube.md)
- MDN Mono-Red Burn by xxxpyro
  - [Decklist](https://www.mtggoldfish.com/archetype/modern-mono-red-burn#paper) on MTGGoldFish
- MDN Mono-Red Prowess by Nicholas Miller
  - [Decklist](https://www.mtggoldfish.com/archetype/modern-mono-red-prowess#paper) on MTGGoldFish
- MDN Mordor Starter Precon by WotC
  - [Decklist](https://magic.wizards.com/en/news/announcements/the-lord-of-the-rings-tales-of-middle-earth-starter-kit-decklists)
    on Wizards
- MDN Orzhov Nazgul Ring Bearer by JayVillain
  - [Decklist](https://aetherhub.com/Deck/nazgul-knights-orzhov-ring-bearer) on Aetherhub
  - [Guide](https://www.youtube.com/watch?v=HizzkL6Sxdg) on YouTube
- MDN Ultra-Budget Real Affinity by SaffronOlive
  - [Decklist](https://www.mtggoldfish.com/deck/4061013) on MTGGoldFish

##### MDN Izzet Prowess by tiyn

This deck is put together by tiyn.
The base of this build is
[MDN Izzet Prowess (Budget) by Xaranthilurozox](https://www.mtggoldfish.com/deck/3311260#paper).

The following resources have been used.

- 1:MDN Izzet Prowess by MoreTimes
  - [Decklist](https://www.mtggoldfish.com/deck/5888133#paper) on MTGGoldFish
- 2:MDN Izzet Prowess by IslandGoSAMe
  - [Guide](https://www.youtube.com/watch?v=htwBuoGM4b8) on [YouTube](/wiki/youtube.md)
- 3:MDN Mono-Red Prowess by Nicholas Miller
  - [Decklist](https://www.mtggoldfish.com/archetype/modern-mono-red-prowess#paper) on MTGGoldFish

The following changes to the deck have been made:

- 2 Dragon's Rage Channeler <- Bedlam Reveler
- 2 Dragon's Rage Channeler <- Stormwing Entity
- 3 Expressive Iteration <- Light Up the Stage
- 1 Expressive Iteration <- Opt
- 2 Mishra's Bauble <- Gut Shot
- 2 Mishra's Bauble <- Opt
- 2 Unholy Heat <- Burst Lightning

The following changes to the sideboard have been made:

- 2 Shattering Spree <- 2 Abrade

The following changes to the deck are currently being considered:

- None

The following changes to the sideboard are currently being considered:

- None

#### Pauper

This section focusses on decks made for the format pauper.

- PAU Rakdos Burn by TiagoFuguete
  - [Decklist](https://mtgdecks.net/Pauper/rakdos-burn-decklist-by-tiagofuguete-1797900) on MTGDecks
- PAU Rakdos Madness by AndreaMengucci
  - [Decklist](https://app.cardboard.live/shared-deck/3283f313-d5c2-11ec-8b34-12f15ef2af51?channel_id=85959522)
    on Cardboard
  - [Guide](https://www.youtube.com/watch?v=RqsXghL1nAg) on [YouTube](/wiki/youtube.md)

##### PAU Rakdos Burn by tiyn

This deck is put together by tiyn.
The base of this build is
[PAU Rakdos Burn by TiagoFuguete](https://mtgdecks.net/Pauper/rakdos-burn-decklist-by-tiagofuguete-1797900).

The following resources have been used.

- 1:PAU Rakdos Madness by AndreaMengucci
  - [Decklist](https://app.cardboard.live/shared-deck/3283f313-d5c2-11ec-8b34-12f15ef2af51?channel_id=85959522)
    on Cardboard
  - [Guide](https://www.youtube.com/watch?v=RqsXghL1nAg) on [YouTube](/wiki/youtube.md)

The following changes to the deck have been made:

- 1 Bump in the Night <- Sovereign's Bite
- 1 Bump in the Night <- End the Festivities
- 1 Bump in the Night <- Duress
- 1 Drossforge Bridge <- Bloodfell Caves
- 1 Drossforge Bridge <- Swamp
- 2 Drossforge Bridge <- Mountain
- 2 Gurmag Angler <- Chain Lightning

The following changes to the sideboard have been made:

- None

The following changes to the deck are currently being considered:

- None

The following changes to the sideboard are currently being considered:

- None

#### Standard

This section focusses on decks made for the format standard.

- STD Izzet Burn Bright by RookerKdag
  - [Decklist](https://www.mtggoldfish.com/deck/5070060#paper) on MTGGoldFish
- STD Mono-Blue Tempo by LabroNico
  - [Decklist](https://www.mtggoldfish.com/deck/5977587#paper) on MTGGoldFish
- STD Mono-Red Burn by Untapped
  - [Decklist](https://mtga.untapped.gg/meta/decks/193/mono-red-burn/AAQAAQLiqiGHmgQBoN8lAAmy0wLbEtbIHZV8SR3GWq2-A9waARTiCQA?tab=overview)
    on Untapped
- STD Zero Rare Rakdos Sacrifice by TheMTGArtisan
  - [Decklist](https://aetherhub.com/Deck/zero-rare-rakdos-sacrifice-842594) on Aetherhub
